==> knative-client-4.10.2-sources.jar: io/fabric8/knative/client/serving/v1/handlers/RevisionHandler.java <==


                        

package io.fabric8.knative.client.serving.v1.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.knative.client.serving.v1.internal.RevisionOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.knative.serving.v1.Revision;
import io.fabric8.knative.serving.v1.RevisionBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class RevisionHandler implements ResourceHandler<Revision, RevisionBuilder> {

  @Override
  public String getKind() {
    return Revision.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "serving.knative.dev/v1";
      }

  @Override
  public Revision create(OkHttpClient client, Config config, String namespace, Revision item) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public Revision replace(OkHttpClient client, Config config, String namespace, Revision item) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public Revision reload(OkHttpClient client, Config config, String namespace, Revision item) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public RevisionBuilder edit(Revision item) {
    return new RevisionBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, Revision item) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Revision item, Watcher<Revision> watcher) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Revision item, String resourceVersion, Watcher<Revision> watcher) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Revision item, ListOptions listOptions, Watcher<Revision> watcher) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(listOptions, watcher);
  }

  @Override
  public Revision waitUntilReady(OkHttpClient client, Config config, String namespace, Revision item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Revision waitUntilCondition(OkHttpClient client, Config config, String namespace, Revision item, Predicate<Revision> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> knative-client-5.3.0-sources.jar: io/fabric8/knative/client/serving/v1/handlers/RevisionHandler.java <==


                        

package io.fabric8.knative.client.serving.v1.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.knative.client.serving.v1.internal.RevisionOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.knative.serving.v1.Revision;
import io.fabric8.knative.serving.v1.RevisionBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class RevisionHandler implements ResourceHandler<Revision, RevisionBuilder> {

  @Override
  public String getKind() {
    return Revision.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "serving.knative.dev/v1";
      }

  @Override
  public Revision create(OkHttpClient client, Config config, String namespace, Revision item, boolean dryRun) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public Revision replace(OkHttpClient client, Config config, String namespace, Revision item, boolean dryRun) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public Revision reload(OkHttpClient client, Config config, String namespace, Revision item) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public RevisionBuilder edit(Revision item) {
    return new RevisionBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, Revision item, boolean dryRun) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Revision item, Watcher<Revision> watcher) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Revision item, String resourceVersion, Watcher<Revision> watcher) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Revision item, ListOptions listOptions, Watcher<Revision> watcher) {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(listOptions, watcher);
  }

  @Override
  public Revision waitUntilReady(OkHttpClient client, Config config, String namespace, Revision item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Revision waitUntilCondition(OkHttpClient client, Config config, String namespace, Revision item, Predicate<Revision> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RevisionOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
